#
# spec file for package gstreamer-plugins-libav
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gst_branch 1.0

Name:           gstreamer-plugins-libav
Version:        1.24.10
Release:        1.1
Summary:        A ffmpeg/libav plugin for GStreamer
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            https://gstreamer.freedesktop.org
Source0:        %{url}/src/gst-libav/gst-libav-%{version}.tar.xz
Source1000:     baselibs.conf

BuildRequires:  gcc-c++
BuildRequires:  meson >= 1.1
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0) >= %{version}
BuildRequires:  pkgconfig(gstreamer-base-1.0) >= %{version}
BuildRequires:  pkgconfig(gstreamer-check-1.0) >= %{version}
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= %{version}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(orc-0.4) >= 0.4.16
BuildRequires:  pkgconfig(zlib)
Requires:       gstreamer >= %{version}
Enhances:       gstreamer

%description
GStreamer is a streaming media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related. Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plug-ins.

This plugin contains the FFmpeg codecs, containing codecs for most popular
multimedia formats.

%package doc
Summary:        GStreamer Streaming-Media Framework Plug-Ins
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description doc
GStreamer is a streaming media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related. Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plug-ins.

This plugin contains the documentation

%prep
%autosetup -n gst-libav-%{version} -p1

%build
%meson \
	-Dpackage-name='openSUSE GStreamer-plugins-libav package' \
	-Dpackage-origin='http://download.opensuse.org' \
	-Ddoc=disabled \
	%{nil}
%meson_build

%install
%meson_install

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_libdir}/gstreamer-%{gst_branch}/libgstlibav.so

%changelog
* Mon Dec  9 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.10:
  + avcodecmap: Use avcodec_get_supported_config() instead of
    struct fields.
  + libav: viddec: provide details if meta has the wrong
    resolution.
  + avviddec: Unlock video decoder stream lock temporarily while
    finishing frames.
* Tue Nov  5 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.9:
  + avviddec: Unlock video decoder stream lock temporarily while
    finishing frames
* Mon Sep 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.8:
  + No changes, stable version bump only.
* Fri Aug 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.7:
  + avdemux: Fix deadlock with FFmpeg 7.x when serialized events
    are received from upstream while opening, such as e.g. APE
    files with tags
  + libav: return EOF when stream is out of data
  + avdemux: Never return 0 from read function, which would lead to
    infinite loops
* Wed Jul 31 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.24.6:
  + Highlighted bugfixes:
  - Fix compatibility with FFmpeg 7.0.
  - qmlglsink: Fix failure to display content on recent Android
    devices.
  - adaptivedemux: Fix handling of closed caption streams.
  - cuda: Fix runtime compiler loading with old CUDA tookit.
  - decodebin3 stream selection handling fixes.
  - d3d11compositor, d3d12compositor: Fix transparent background
    mode with YUV output.
  - d3d12converter: Make gamma remap work as intended.
  - h264decoder: Update output frame duration for interlaced
    video when second field frame is discarded.
  - macOS audio device provider now listens to audio devices
    being added/removed at runtime.
  - Rust plugins: audioloudnorm, s3hlssink, gtk4paintablesink,
    livesync and webrtcsink fixes.
  - videoaggregator: preserve features in non-alpha caps for
    subclasses with non-system memory sink caps.
  - vtenc: Fix redistribute latency spam.
  - v4l2: fixes for complex video formats.
  - va: Fix strides when importing DMABUFs, dmabuf handle leaks,
    and blocklist unmaintained Intel i965 driver for encoding.
  - waylandsink: Fix surface cropping for rotated streams.
  - webrtcdsp: Enable multi_channel processing to fix handling of
    stereo streams.
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements.
* Thu Jun 27 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.5:
  + Highlighted bugfixes:
  - webrtcsink: Support for AV1 via nvav1enc, av1enc or rav1enc
    encoders
  - AV1 RTP payloader/depayloader fixes to work correctly with
    Chrome and Pion WebRTC
  - av1parse, av1dec error handling/robustness improvements
  - av1enc: Handle force-keyunit events properly for WebRTC
  - decodebin3: selection and collection handling improvements
  - hlsdemux2: Various fixes for discontinuities, variant
    switching, playlist updates
  - qml6glsink: fix RGB format support
  - rtspsrc: more control URL handling fixes
  - v4l2src: Interpret V4L2 report of sync loss as video signal
    loss
  - d3d12 encoder, memory and videosink fixes
  - vtdec: more robust error handling, fix regression
  - ndi: support for NDI SDK v6
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements
- Please see https://gstreamer.freedesktop.org/releases/1.24/ for
  changes between 1.24.0 and this version and even more in-depth
  info.
* Tue Mar  5 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.24.0:
  * Highlights
  - New Discourse forum and Matrix chat space
  - New Analytics and Machine Learning abstractions and elements
  - Playbin3 and decodebin3 are now stable and the default in
    gst-play-1.0, GstPlay/GstPlayer
  - The va plugin is now preferred over gst-vaapi and has higher
    ranks
  - GstMeta serialization/deserialization and other GstMeta
    improvements
  - New GstMeta for SMPTE ST-291M HANC/VANC Ancillary Data
  - New unixfd plugin for efficient 1:N inter-process
    communication on Linux
  - cudaipc source and sink for zero-copy CUDA memory sharing
    between processes
  - New intersink and intersrc elements for 1:N pipeline
    decoupling within the same process
  - Qt5 + Qt6 QML integration improvements including qml6glsrc,
    qml6glmixer, qml6gloverlay, and qml6d3d11sink elements
  - DRM Modifier Support for dmabufs on Linux
  - OpenGL, Vulkan and CUDA integration enhancements
  - Vulkan H.264 and H.265 video decoders
  - RTP stack improvements including new RFC7273 modes and more
    correct header extension handling in depayloaders
  - WebRTC improvements such as support for ICE consent
    freshness, and a new webrtcsrc element to complement
    webrtcsink
  - WebRTC signallers and webrtcsink implementations for LiveKit
    and AWS Kinesis Video Streams
  - WHIP server source and client sink, and a WHEP source
  - Precision Time Protocol (PTP) clock support for Windows and
    other additions
  - Low-Latency HLS (LL-HLS) support and many other HLS and DASH
    enhancements
  - New W3C Media Source Extensions library
  - Countless closed caption handling improvements including new
    cea608mux and cea608tocea708 elements
  - Translation support for awstranscriber
  - Bayer 10/12/14/16-bit depth support
  - MPEG-TS support for asynchronous KLV demuxing and segment
    seeking, plus various new muxer features
  - Capture source and sink for AJA capture and playout cards
  - SVT-AV1 and VA-API AV1 encoders, stateless AV1 video decoder
  - New uvcsink element for exporting streams as UVC camera
  - DirectWrite text rendering plugin for windows
  - Direct3D12-based video decoding, conversion, composition, and
    rendering
  - AMD Advanced Media Framework AV1 + H.265 video encoders with
    10-bit and HDR support
  - AVX/AVX2 support and NEON support on macOS on Apple ARM64
    CPUs via new liborc
  - GStreamer C# bindings have been updated
  - Rust bindings improvements and many new and improved Rust
    plugins
  - Rust plugins now shipped in packages for all major platforms
    including Android and iOS
  - Lots of new plugins, features, performance improvements and
    bug fixes
  * For more detailed information on this update, please see
    https://gstreamer.freedesktop.org/releases/1.24/
- Remove patch reduce-required-meson.patch since meson 1.1 is
  really required now.
* Thu Feb  1 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.9:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Thu Jan  4 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.8:
  + avviddec: Unlock stream lock while waiting for decoded frame.
    Fixes potential deadlock
  + avviddec: Calculate latency only for fixed framerate
- Rebase reduce-required-meson.patch.
* Wed Nov 15 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.7:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Fri Sep 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.6:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Tue Jul 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.5:
  + No changes
- Rebase reduce-required-meson.patch.
* Mon Jun 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.4:
  + No changes.
- Rebase reduce-required-meson.patch.
* Wed May 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.3:
  + avviddec: Temporarily unlock stream lock while flushing
    buffers.
  + Random freeze and deadlock in ffmpegviddec flush and get_buffer
    while seeking.
- Rebase reduce-required-meson.patch.
* Wed Apr 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.2:
  + avdec_h264 pipeline freeze with FFmpeg6
  + avdeinterlace, avmux: fix element reference leak
  + avviddec: Drop decoder stream lock when calling send_packet
- Rebase patch.
* Thu Mar  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.1:
  + avauddec, avviddec: Free packet side data after usage
  + avviddec:
  - Change AV_CODEC_CAP_AUTO_THREADS->AV_CODEC_CAP_OTHER_THREADS
    to fix build against newer ffmpeg versions
  - Don't take ffmpeg timestamps verbatim but only use them to
    calculate DTS
  + Memory leak in 'av_packet_add_side_data' in
    /lib/x86_64-linux-gnu/libavcodec.so reading the file
    clock_odd_size_RLE_g1597902.avi
- Rebase patch with quilt.
* Wed Mar  1 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to reduce the required meson version to 0.61.0 since
  that's what we have in SLE 15:
  * reduce-required-meson.patch
* Wed Jan 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.0:
  + Please see changes in gstreamer main package, major version
    bump.
* Fri Dec 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.5:
  + avdec_h265: Fix endless renegotiation with alternate
    interlacing
  + avviddec: Avoid flushing on framerate changes
* Wed Nov  2 2022 Cristian Rodríguez <crrodriguez@opensuse.org>
- Remove unused BuildRequire on yasm.
* Sat Oct 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.4:
  + avauddec:
  - Fix regression with WMA files, would throw an error at EOS.
  - Fix unnecessary reconfiguration if the audio layout isn't
    specified.
  + libav: Fix for APNG encoder property registration.
  + Failure to decode end of WMA file.
* Wed Jun 22 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 1.20.3:
  + No Changes
* Mon May  9 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.20.2:
  + video decoders: fix frame leak on negotiation error
  + Fix build on systems without C++ compiler
  + avviddec: Remove vc1/wmv3 override (fixing crash with FFmpeg 5
  + Segfaults on ASF/WMV files with FFMPEG 5.0+
* Wed Apr 20 2022 Antonio Larrosa <alarrosa@suse.com>
- Change the license to LGPL-2.1-or-later as specified in
  the COPYING file
* Fri Mar 18 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.20.1:
  + No changes
* Fri Feb  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.0:
  + Development in GitLab was switched to a single git repository
    containing all the modules
  + GstPlay: new high-level playback library, replaces GstPlayer
  + WebM Alpha decoding support
  + Encoding profiles can now be tweaked with additional
    application-specified element properties
  + Compositor: multi-threaded video conversion and mixing
  + RTP header extensions: unified support in RTP depayloader and
    payloader base classes
  + SMPTE 2022-1 2-D Forward Error Correction support
  + Smart encoding (pass through) support for VP8, VP9, H.265 in
    encodebin and transcodebin
  + Runtime compatibility support for libsoup2 and libsoup3
    (libsoup3 support experimental)
  + Video decoder subframe support
  + Video decoder automatic packet-loss, data corruption, and
    keyframe request handling for RTP / WebRTC / RTSP
  + mp4 and Matroska muxers now support profile/level/resolution
    changes for H.264/H.265 input streams (i.e. codec data changing
    on the fly)
  + mp4 muxing mode that initially creates a fragmented mp4 which
    is converted to a regular mp4 on EOS
  + Audio support for the WebKit Port for Embedded (WPE) web page
    source element
  + CUDA based video color space convert and rescale elements and
    upload/download elements
  + NVIDIA memory:NVMM support for OpenGL glupload and gldownload
    elements
  + Many WebRTC improvements
  + The new VA-API plugin implementation fleshed out with more
    decoders and new postproc elements
  + AppSink API to retrieve events in addition to buffers and
    buffer lists
  + AppSrc gained more configuration options for the internal queue
    (leakiness, limits in buffers and time, getters to read current
    levels)
  + Updated Rust bindings and many new Rust plugins
  + Improved support for custom minimal GStreamer builds
  + Support build against FFmpeg 5.0
  + Linux Stateless CODEC support gained MPEG-2 and VP9
  + Windows Direct3D11/DXVA decoder gained AV1 and MPEG-2 support
  + Lots of new plugins, features, performance improvements and bug
    fixes
- Drop add-gpl-option.patch: It no longer applies, but what is more
  important is that it does not make sense. Adding the gpl option
  only mattered when building the included ffmpeg sources gst-libav
  had when it still supported autotools. We can not change how the
  external ffmpeg we depend on is built, we take what we are given
  in this case. Our ffmpeg is built with GPL-3.0-or-later as
  license, hence change the license for this package to
  GPL-3.0-or-later in order to reflect that fact.
- Drop Supplements and Requires. No longer autoinstall this package
  as when gst-libav is not available, the hardwaresupported codecs
  in gst-bad finaly get to shine and strutt their wings.
  Upstream sets basicly all decoders from gst-libav to a higher
  preferance score, as they assume if you have gst-libav installed,
  you want to use it for almost everything.
* Fri Feb  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.6:
  + avcodecmap: Add support for GBRA_10LE/BE.
* Thu Sep 16 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Stop building doc sub-package, we will in the future use
  upstreams own standalone doc package. Following this: Drop
  hotdoc BuildRequires, and pass doc=disabled to meson.
* Wed Sep 15 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.5:
  + avmux:
  - Blacklist ttml subtitles (fixes crash with ffmpeg >= 4.4)
  - Fix segfault when a plugin's long_name is NULL
  + avviddec:
  - Fix size of linesize parameter
  - Take into account coded_height for pool
  + avdemux: fix build with FFmpeg 4.4
* Tue Aug 24 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update add-gpl-option.patch: the proper language to be used is
  cpp, not c++; fixes build with meson 0.59.
* Tue Mar 30 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.18.4:
  + h264 encoder: append encoder exposure to aud
  + postproc: Fix a problem of propose_allocation when passthrough
  + glx: Iterate over FBConfig and select 8 bit color size
* Sat Jan 16 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.3:
  + avauddec: Drain decoder on decoding failure, fixes timestamps
    after decoding errors
* Wed Dec  9 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.2:
  + avauddec: Check planar-ness of frame rather than context, fixes
    issue with aptX HD decoding.
* Wed Nov 25 2020 Frederic Crozat <fcrozat@suse.com>
- Fix identifer of package name when building plugin.
* Wed Oct 28 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.18.1:
  + Highlighted bugfixes in 1.18.1
  - important security fixes
  - bug fixes and memory leak fixes
  - various stability and reliability improvements
  + gst-libav changes:
  - avaudenc/avvidenc: Reopen encoding session if it's required
  - avauddec/audenc/videnc: Don't return GST_FLOW_EOS when draining
  - avauddec/avviddec: Avoid dropping non-OK flow return
  - avcodecmap: Enable 24 bit WMA Lossless decoding
* Fri Sep 18 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.18.0:
  + Highlights:
  - GstTranscoder: new high level API for applications to
    transcode media files from one format to another
  - High Dynamic Range (HDR) video information representation
    and signalling enhancements
  - Instant playback rate change support
  - Active Format Description (AFD) and Bar Data support
  - RTSP server and client implementations gained ONVIF trick
    modes support
  - Hardware-accelerated video decoding on Windows via
    DXVA2/Direct3D11
  - Microsoft Media Foundation plugin for video capture and
    hardware-accelerated video encoding on Windows
  - qmlgloverlay: New overlay element that renders a QtQuick
    scene over the top of an input video stream
  - imagesequencesrc: New element to easily create a video
    stream from a sequence of jpeg or png images
  - dashsink: New sink to produce DASH content
  - dvbsubenc: New DVB Subtitle encoder element
  - MPEG-TS muxing now also supports TV broadcast compliant
    muxing with constant bitrate muxing and SCTE-35 support
  - rtmp2: New RTMP client source and sink element from-scratch
    implementation
  - svthevcenc: New SVT-HEVC-based H.265 video encoder
  - vaapioverlay: New compositor element using VA-API
  - rtpmanager gained support for Google's Transport-Wide
    Congestion Control (twcc) RTP extension
  - splitmuxsink and splitmuxsrc gained support for auxiliary
    video streams
  - webrtcbin now contains some initial support for
    renegotiation involving stream addition and removal
  - RTP support was enhanced with new RTP source and sink
    elements to easily set up RTP streaming via rtp:// URIs
  - avtp: New Audio Video Transport Protocol (AVTP) plugin for
    Time-Sensitive Applications
  - Support for the Video Services Forum's Reliable Internet
    Stream Transport (RIST) TR-06-1 Simple Profile
  - Universal Windows Platform (UWP) support
  - rpicamsrc: New element for capturing from the Raspberry Pi
    camera
  - RTSP Server TCP interleaved backpressure handling
    improvements as well as support for Scale/Speed headers
  - GStreamer Editing Services gained support for nested
    timelines, per-clip speed rate control and the OpenTimelineIO
    format.
  - Autotools build system has been removed in favour of Meson
- Add patch to bring back the support to build the project with
  a GPL license, which was removed when configure was replaced by
  meson:
  * add-gpl-option.patch
* Wed Dec  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.2:
  + avvidenc: Fix error propagation
  + avdemux: Fix segmentation fault if long_name is NULL
  + avviddec:
  - Fix huge leak caused by circular reference
  - Enforce allocate new AVFrame per input frame
  + avdec_mpeg2video (and probably more): Fix huge memory leak.
- Drop patches fixed upstream:
  + gst-libav-fix-mem-leak.patch
  + gst-libav-fix-segfault.patch
* Thu Nov 28 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add gst-libav-fix-mem-leak.patch: Fix memory leak.
- Add gst-libav-fix-segfault.patch: Fix segmentation fault.
* Tue Sep 24 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.1:
  + See main gstreamer package for changelog.
* Sun Jun 16 2019 mgorse@suse.com
- Update to version 1.16.0:
  + Highlights
  - GStreamer WebRTC stack gained support for data channels for
    peer-to-peer communication based on SCTP, BUNDLE support, as
    well as support for multiple TURN servers.
  - AV1 video codec support for Matroska and QuickTime/MP4
    containers and more configuration options and supported
    input formats for the AOMedia AV1 encoder
  - Support for Closed Captions and other Ancillary Data in video
  - Support for planar (non-interleaved) raw audio
  - GstVideoAggregator, compositor and OpenGL mixer elements are
    now in -base
  - New alternate fields interlace mode where each buffer carries
    a single field
  - WebM and Matroska ContentEncryption support in the Matroska
    demuxer
  - new WebKit WPE-based web browser source element
  - Video4Linux: HEVC encoding and decoding, JPEG encoding, and
    improved dmabuf import/export
  - Hardware-accelerated Nvidia video decoder gained support for
    VP8/VP9 decoding, whilst the encoder gained support for
    H.265/HEVC encoding.
  - Many improvements to the Intel Media SDK based
    hardware-accelerated video decoder and encoder plugin (msdk):
    dmabuf import/export for zero-copy integration with other
    components; VP9 decoding; 10-bit HEVC encoding; video
    post-processing (vpp) support including deinterlacing; and
    the video decoder now handles dynamic resolution changes.
  - The ASS/SSA subtitle overlay renderer can now handle multiple
    subtitles that overlap in time and will show them on screen
    simultaneously
  - The Meson build is now feature-complete (*) and it is now the
    recommended build system on all platforms. The Autotools
    build is scheduled to be removed in the next cycle.
  - The GStreamer Rust bindings and Rust plugins module are now
    officially part of upstream GStreamer.
  - The GStreamer Editing Services gained a gesdemux element that
    allows directly playing back serialized edit list with
    playbin or (uri)decodebin
  - Many performance improvements
- Drop gst-libav-port-ffmpeg4.patch: fixed upstream.
- Require libavcodec 58, per configure.ac.
* Fri May 31 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.5:
  + libav: Update internal snapshot to ffmpeg n3.4.6.
  + avdemux: fix negative pts if start_time is bigger than the ts.
* Wed Oct  3 2018 bjorn.lie@gmail.com
- Update to version 1.14.4:
  + Bugfix release, please see .changes in gstreamer main package.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 1.14.3:
  + Bugfix release, please see .changes in gstreamer main package.
* Mon Jul 23 2018 bjorn.lie@gmail.com
- Update to version 1.14.2:
  + Update docs.
  + libav: Fix symbol redefine build error.
  + avdemux: fix memory leaks.
- Rebase gst-libav-port-ffmpeg4.patch with quilt.
* Sun May 20 2018 bjorn.lie@gmail.com
- Update to version 1.14.1:
  + GstPad: Fix race condition causing the same probe to be called
    multiple times
  + Fix occasional deadlocks on windows when outputting debug
    logging
  + Fix debug levels being applied in the wrong order
  + GIR annotation fixes for bindings
  + audiomixer, audioaggregator: fix some negotiation issues
  + gst-play-1.0: fix leaving stdin in non-blocking mode after exit
  + flvmux: wait for caps on all input pads before writing header
    even if source is live
  + flvmux: don't wake up the muxer unless there is data, fixes
    busy looping if there's no input data
  + flvmux: fix major leak of input buffers
  + rtspsrc, rtsp-server: revert to RTSP RFC handling of
    sendonly/recvonly attributes
  + rtpvrawpay: fix payloading with very large mtu sizes where
    everything fits into a single RTP packet
  + v4l2: Fix hard-coded enabled v4l2 probe on Linux/ARM
  + v4l2: Disable DMABuf for emulated formats when using libv4l2
  + v4l2: Always set colorimetry in S_FMT
  + asfdemux: Set stream-format field for H264 streams and handle
    H.264 in bytestream format
  + x265enc: Fix tagging of keyframes on output buffers
  + ladspa: Fix critical during plugin load on Windows
  + decklink: Fix COM initialisation on Windows
  + h264parse: fix re-use across pipeline stop/restart
  + mpegtsmux: fix force-keyframe event handling and PCR/PMT
    changes that would confuse some players with generated HLS
    streams
  + adaptivedemux: Support period change in live playlist
  + rfbsrc: Fix support for applevncserver and support NULL pool in
    decide_allocation
  + jpegparse: Fix APP1 marker segment parsing
  + h265parse: Make caps writable before modifying them, fixes
    criticals
  + fakevideosink: request an extra buffer if enable-last-sample is
    enabled
  + wasapisrc: Don't provide a clock based on WASAPI's clock
  + wasapi: Only use audioclient3 when low-latency, as it might
    otherwise glitch with slow CPUs or VMs
  + wasapi: Don't derive device period from latency time, should
    make it more robust against glitches
  + audiolatency: Fix wave detection in buffers and avoid bogus pts
    values while starting
  + msdk: fix plugin load on implementations with only HW support
  + msdk: dec: set framerate to the driver only if provided, not in
    0/1 case
  + msdk: Don't set extended coding options for JPEG encode
  + rtponviftimestamp: fix state change function init/reset causing
    races/crashes on shutdown
  + decklink: fix initialization failure in windows binary
  + ladspa: Fix critical warnings during plugin load on Windows and
    fix dependencies in meson build
  + gl: fix cross-compilation error with viv-fb
  + qmlglsink: make work with eglfs_kms
  + rtspclientsink: Don't deadlock in preroll on early close
  + rtspclientsink: Fix client ports for the RTCP backchannel
  + rtsp-server: Fix session timeout when streaming data to client
    over TCP
  + vaapiencode: h264: find best profile in those available, fixing
    negotiation errors
  + vaapi: remove custom GstGL context handling, use GstGL instead.
    Fixes GL Context sharing with WebkitGtk on wayland
  + gst-editing-services: various fixes
  + gst-python: bump pygobject req to 3.8;
    fix GstPad.set_query_function(); dist autogen.sh and
    configure.ac in tarball
  + g-i: pick up GstVideo-1.0.gir from local build directory in
    GstGL build
  + g-i: update constant values for bindings
  + avoid duplicate symbols in plugins across modules in static
    builds
  + ... and many, many more!
* Tue May  8 2018 bjorn.lie@gmail.com
- Add gst-libav-port-ffmpeg4.patch: Port to ffmpeg 4.0. No longer
  use explicit ffmpeg3 versions (bgo#792900).
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Sun Apr 22 2018 bjorn.lie@gmail.com
- Explicitly version pkgconfig(libavcodec), pkgconfig(libavfilter),
  pkgconfig(libavformat), pkgconfig(libavutil) and
  pkgconfig(libswscale) BuildRequires to less than the symbol
  versions provided by ffmpeg4 branch until upstream catches up.
  Currently provided by new ffmpeg3 compatability package.
* Mon Apr 16 2018 bjorn.lie@gmail.com
- Update to version 1.14.0:
  + Highlights:
  - WebRTC support: real-time audio/video streaming to and from
    web browsers;
  - Experimental support for the next-gen royalty-free AV1 video
    codec;
  - Video4Linux: encoding support, stable element names and
    faster device probing;
  - Support for the Secure Reliable Transport (SRT) video
    streaming protocol;
  - RTP Forward Error Correction (FEC) support (ULPFEC);
  - RTSP 2.0 support in rtspsrc and gst-rtsp-server;
  - ONVIF audio backchannel support in gst-rtsp-server and
    rtspsrc;
  - playbin3 gapless playback and pre-buffering support;
  - Tee, our stream splitter/duplication element, now does
    allocation query aggregation which is important for efficient
    data handling and zero-copy;
  - QuickTime muxer has a new prefill recording mode that allows
    file import in Adobe Premiere and FinalCut Pro while the file
    is still being written;
  - rtpjitterbuffer fast-start mode and timestamp offset
    adjustment smoothing;
  - souphttpsrc connection sharing, which allows for connection
    reuse, cookie sharing, etc;
  - nvdec: new plugin for hardware-accelerated video decoding
    using the NVIDIA NVDEC API;
  - Adaptive DASH trick play support;
  - ipcpipeline: new plugin that allows splitting a pipeline
    across multiple processes;
  - Major gobject-introspection annotation improvements for large
    parts of the library API;
  - GStreamer C# bindings have been revived and seen many updates
    and fixes;
  - The externally maintained GStreamer Rust bindings had many
    usability improvements and cover most of the API now.
    Coinciding with the 1.14 release, a new release with the 1.14
    API additions is happening.
  + Updated translations.
* Thu Mar 29 2018 bjorn.lie@gmail.com
- Update to version 1.12.5:
  + Bugs fixed: bgo#791783, bgo#789379, bgo#788481.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Jan 26 2018 bjorn.lie@gmail.com
- Add conditional libavcodec.so(unrestricted) Requires, pull in the
  full codecpack when installing package from third party repos who
  build libavcodec.
* Thu Dec 14 2017 zaitor@opensuse.org
- Drop gst-libav-ffmpeg-3.4-hackfix.patch: Workaround applied
  upstream in ffmpeg.
* Mon Dec 11 2017 zaitor@opensuse.org
- Update to version 1.12.4:
  + libav: Update to ffmpeg n3.3.5.
  + Bugs fixed: bgo#787795.
- Drop gstreamer-plugins-libav-avdemux-reset.patch: Fixed upstream.
* Fri Nov 10 2017 zaitor@opensuse.org
- Add gstreamer-plugins-libav-avdemux-reset.patch: avdemux: reset
  to 0 negative pts for us pts are unsigned so reset to 0 negative
  pts returned from libav. This is better than outputs completly
  wrong timestamps (bgo#787795).
- Split out doc sub-package.
- Cleanup with spec-cleaner.
* Fri Nov 10 2017 zaitor@opensuse.org
- Add gst-libav-ffmpeg-3.4-hackfix.patch: Workaround api change in
  ffmpeg 3.4 and newer (bgo#789193).
* Mon Sep 18 2017 zaitor@opensuse.org
- Update to version 1.12.3:
  + Bugs fixed: bgo#784735.
* Sat Jul 15 2017 dimstar@opensuse.org
- Update to version 1.12.2:
  + avmux: Blacklist scc muxer.
- Remove the embedded libav sources to ensure we only use the
  system provided (and legally validated) ffmpeg libs.
* Wed Jun 21 2017 zaitor@opensuse.org
- Update to version 1.12.1:
  + Bugs fixed: bgo#694416, bgo#782700.
- Drop gst-libav-disable-cuvid-codecs.patch: Fixed upstream.
* Wed Jun  7 2017 davejplater@gmail.com
- Add patch gst-libav-disable-cuvid-codecs.patch fixes boo#1039163.
* Tue May  9 2017 zaitor@opensuse.org
- Update to version 1.12.0:
  + No changes, stable bump only.
- Changes from version 1.11.91:
  + libav: Update to ffmpeg n3.3.
  + avaudenc/dec: Blacklist more PCM decoders/encoders.
- Changes from version 1.11.90:
  + Bugs fixed: bgo#767938, bgo#780317.
- Stop passing --disable-fatal-warnings to configure, not needed on
  stable releases.
* Fri Feb 24 2017 zaitor@opensuse.org
- Update to version 1.11.2:
  + libav: Update to ffmpeg n3.2.4.
  + Meson build fixes.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.11.1:
  + Bugs fixed: bgo#750882, bgo#773672, bgo#776700.
- Temporarily pass --disable-fatal-warnings to configure, needed
  since we are on the unstable branch.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.10.4:
  + Update internal ffmpeg to 3.2.4.
* Thu Feb  9 2017 zaitor@opensuse.org
- Require building against at least ffmpeg 3.0 (bgo#778283).
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 1.10.3:
  + Bugs fixed: bgo#775516.
* Fri Dec  9 2016 zaitor@opensuse.org
- Update to version 1.10.2:
  + libav: Update to ffmpeg n3.2.1.
  + meson: update version.
- Changes from version 1.10.1:
  + Bugs fixed: bgo#774215, bgo#774278, bgo#774398.
- Changes from version 1.10.0:
  + Various bug fixes.
* Thu Sep 22 2016 zaitor@opensuse.org
- Update to version 1.8.3:
  + libgstlibav fails on Linux (bgo#769809).
- Tweak summary to avoid a pointless rpmlint warning.
* Fri Jul 29 2016 jengelh@inai.de
- Improve summary/description
* Wed Jun 15 2016 zaitor@opensuse.org
- Update to version 1.8.2:
  + bgo#760266: avenc_mpeg4/mpeg2video: Segmentation fault when
    stopping the pipeline.
  + bgo#765797: avauddec: a/v sync issues with broken streams.
  + bgo#766362: avvidec: Report the latency once we're fully
    configured.
* Tue May  3 2016 zaitor@opensuse.org
- Disable gstreamer-plugins-libav-automake_version.patch: We have
  no need for it currently. At the same time replace automake and
  autoconf for libtool BuildRequires.
- Drop libva-devel and libvdpau-devel BuildRequires: vaapi and
  vdpau support in gstreamer universe is provided by
  gstreamer-plugins-vaapi (in conjecture with libva-vdpau-driver if
  using nvidia binary driver), and pulling these into buildroot
  serves no purpose.
- Add a gstreamer Supplements: Help pull in this package as long as
  gstreamer is installed.
* Thu Apr 21 2016 zaitor@opensuse.org
- Update to version 1.8.1:
  + bgo#765319: avdeinterlace: only green screen since 1.7.2.
* Wed Apr 20 2016 develop7@develop7.info
- Depend on appropriate gstreamer to prevent installing
  gstreamer-plugins-libav-1.8.x in systems with gstreamer < 1.8.x.
* Fri Apr 15 2016 zaitor@opensuse.org
- Update to version 1.8.0:
  + 'configure' using system libav always fails with "Uncompatible
    libavcodec found" (bgo#763940).
  + Bugs fixed: bgo#757498.
- Drop avdeinterlace-Chain-up-to-parent-class-dispose.patch,
  avdeinterlace-Port-non-deprecated-AVFilter-API.patch,
  libav-Bitrate-field-changed-from-int-to-int64t-fix.patch and
  libav-Remove-usage-of-deprecated-API.patch: Fixed upstream.
* Mon Feb 29 2016 joerg.lorenzen@ki.tng.de
- Added avdeinterlace-Chain-up-to-parent-class-dispose.patch,
  avdeinterlace-Port-non-deprecated-AVFilter-API.patch,
  libav-Bitrate-field-changed-from-int-to-int64t-fix.patch and
  libav-Remove-usage-of-deprecated-API.patch to build against
  ffmpeg-3.0 libraries (found on GNOME Bugzilla, see bgo#757498).
- Added gstreamer-plugins-libav-automake_version.patch to enable
  build with automake 1.13.
* Fri Feb 19 2016 joerg.lorenzen@ki.tng.de
- Build shared against ffmpeg-2.8 libraries.
* Fri Jan 22 2016 malcolmlewis@opensuse.org
- Update to version 1.6.3:
  + avviddec: remove realvideo slice_offset handling.
  + avcodecmap: Add special mapping for mono channel layouts.
  + libav: Update to ffmpeg n2.8.5.
- Changes from version 1.6.2:
  + libav: Update to n2.8.3.
  + avviddec: Make sure to use a buffer pool with the correct
    width/height configured on it for pushing buffers downstream.
  + avviddec: Fix structure memory leak.
  + avviddec: Don't fallback on allocation failure.
  + avvidenc: Fix frame memory leak.
  + avdemux: Fix string memory leaks.
* Tue Nov 24 2015 malcolmlewis@opensuse.org
- Move license back to gpl for better support.
- Add xz to build requires for lzma support.
* Thu Nov 19 2015 malcolmlewis@opensuse.org
- Update to version 1.6.1:
  + avviddec: Fix bufferpool config double free by taking a copy as
    needed.
  + libav: Update to n2.8.1.
  + avviddec: only free config when pool doesn't take ownership
    (CID#1320708).
  + avcodecmap: Don't allocate dummy codec data anymore, it causes
    crashes nowadays.
  + avvidenc: Pass the correct user_data to
    gst_buffer_new_wrapped_full().
- Changes from version 1.6.0:
  + No changes, just a version bump.
- Changes from version 1.5.91:
  + avvidec: increase default alignment to 32 bytes (bgo#754120).
  + avvideodec: ensure required mem alignment fixing avdec_h265
    crashes with ximagesink/glimagesink (bgo#754120).
  + libav: Update to ffmpeg n2.8 (bgo#754920).
  + avvid/audenc: Set some tags in the output for downstream's
    info.
  + avviddec: Fix pool reallocation logic (bgo#753869).
- Changes from version 1.5.90:
  + aviddec: Re-enable direct rendering (bgo#752802).
  + avvidenc: use template subset check for accept-caps.
  + avaudenc: use pad template caps for accept-caps.
  + avaudenc: remove useless getcaps method.
  + avvidenc: remove useless getcaps method.
  + avauddec: let audiodecoder call the default pad query handler.
  + avviddec: let videodecoder call the default pad query handler.
  + libav: Update to n2.7.2
  + avviddec: use template caps intersection for accept-caps
    (bgo#753623).
  + avauddec: use template caps intersection for accept-caps
    (bgo#753623).
  + Map ffmpeg metadata to GStreamer tags (bgo#566605).
  + avviddec: Remove unused force parameter.
  + avviddec: Use caps-like size in get_buffer2().
  + avviddec: Reset current_dr on close and when not chosing it
    (bgo#753189).
  + avviddec: Disable direct rendering (bgo#752802).
  + avviddec: Get code out of loop.
  + avviddec: Only create the AVBuffer once the stride is
    validated.
  + avviddec: Re-enable direct rendering.
  + avauddec: Read channels from the channels field (bgo#752186).
  + avviddec: Ignore negotiation error on shutdown (bgo#752800).
  + avauddec: Access field using accessors.
  + Add support for musepack (mpc) sv8 audio (bgo#732682).
  + avviddec: fix slice_offset memory leak (bgo#752404).
  + Update mailing list in doap file.
  + Make the LGPL build the default and require --enable-gpl to
    build a GPL licensed version.
  + avmux: Blacklist some subtitle and adaptive streaming muxers'
  + Switch from libav v11.4 to ffmpeg n2.7.1 (bgo#751607).
  + avaudenc: Remember how many samples the codec consumed for
    telling the base class.
  + avauddec: Ensure input buffers have
    FF_INPUT_BUFFER_PADDING_SIZE padding, which is required by
    avcodec_decode_audio4 ().
  + avmux: Ignore stream_segment,ssegment muxer that is provided by
    ffmpeg.
  + avvidenc: Fix compiler warning.
  + avvidenc: Set AVFrame flags for interlacing per frame and not
    in set_format().
  + av{aud,vid}enc: Create wrapped output buffers with
    GST_MEMORY_FLAG_READONLY.
  + avvidenc: Properly wrap and free the output AVPackets generated
    during draining.
  + avvidenc: Make sure to keep input data alive until libav is
    done with it.
  + avaudenc: Make sure to keep input data alive until libav is
    done with it.
  + av{aud,vid}enc: Stop using deprecated AVFrame APIs.
  + avauddec: Remove custom buffer allocation function.
  + avauddec: Use undeprecated AVFrame API.
  + avviddec: Free frame before the codec is freed.
  + avviddec: Use undeprecated AVFrame API and unref frame once
    we're done with it.
  + avauddec: Negotiate based on the AVFrame instead of just the
    AVCodecContext.
  + avviddec: Use the new get_buffer2() API instead of the
    deprecated APIs.
  + avviddec: Also proxy the data/size pointers for our wrapper
    AVBufferRef.
  + codecmap: add vp9 mapping.
  + avviddec: Wrap the original AVBufferRef in our own buffer for
    the destroy function.
  + avviddec: libav will already copy the reordered_opaque pointer
    for us.
  + avviddec: Negotiate based on the AVFrame information, not the
    context information (bgo#750865).
- Changes from version 1.5.2:
  + avcodec: Check against codec format list (bgo#750398).
  + viddec: Replicate any 3D/multiview info from input caps onto
    output.
  + docs: remove variables that we define in the snippet from
    common.
- Changes from version 1.5.1:
  + avviddec: Release stream lock while calling
    avcodec_decode_video2() (bgo#726020).
  + avviddec: Post error message before returning a flow error.
  + check: Use GST_CHECK_MAIN () macro everywhere.
  + Makefile.am: Make top-level 'check-torture' and
    'check-valgrind' targets functional
  + avcodecmap: Use video/x-cavs mime type instead of
    video/x-gst-av-cavs (bgo#727731).
  + configure: don't disable Chinese AVS (cavs) decoder
    (bgo#727731).
  + avauddev: Unref decoded AVFrame after we're done with it.
  + libav: Update to v11.4.
  + configure: bump automake requirement to 1.14 and autoconf to
    2.69 (bgo#747624).
  + avdemux: resurrect some flow return handling (bgo#744572).
  + libav: Update to v11.3.
  + avdemux: fix double semicolon.
  + libav: Add support for 10 bit planar AYUV formats.
  + libav: Change from deprecated PIX_FMT_* to AV_PIX_FMT_*.
  + avviddec: Don't copy padding if handling a frame failed.
  + avviddec: If a flow return during draining is not OK, don't
    drain any further.
  + avviddec: Error out if we try to allocate a buffer without
    being negotiated.
  + avdemux: remove duplicate goto block.
  + avdemux: check AVIO Context has been allocated.
  + gstavviddec: Add drain() vfunc implementation that does the
    same as finish() (bgo#734617).
  + avviddec: Implement SKIP and new SKIP_KEY_UNITS_ONLY flags
    (bgo#735666).
  + libav: Update to v11.2.
  + av: use GMutex instead of deprecated GStaticMutex (bgo#740822).
- Drop enable-vdpau.patch, see boo#951150.
- Update license change to LGPL-2.1+.
* Fri Dec 26 2014 zaitor@opensuse.org
- Update to version 1.4.5:
  + videodec: Ensure update_pool is initialized.
* Fri Nov 14 2014 zaitor@opensuse.org
- Update to version 1.4.4:
  + No changes, version bump to keep in sync with gst-suite.
* Sat Oct  4 2014 zaitor@opensuse.org
- Update to version 1.4.3:
  + avauddec: Keep draining buffers from libav until libav says so.
- Changes from version 1.4.2:
  + avviddec:
  - After draining frames, flush the libav decoder.
  - Keep draining buffers from libav until libav says so.
  + libav: Update to v10.5.
* Thu Aug 28 2014 zaitor@opensuse.org
- Update to version 1.4.1:
  + avvidec: Decoded frames lost on EOS (bgo#734608).
  + libav: Update to v10.4.
* Tue Jul 22 2014 zaitor@opensuse.org
- Update to version 1.4.0:
  + The stable 1.4 release series is API and ABI compatible with
    1.0.x, 1.2.x and any other 1.x release series in the future.
    Compared to 1.2.x it contains some new features and more
    intrusive changes that were considered too risky as a bugfix.
  + libav: Update to v10.2.
  + Add the now built html help files to doc.
* Sun May  4 2014 zaitor@opensuse.org
- Update to version 1.2.4:
  + Bugs fixed: avdec_h264, matroskademux: crash while seeking
    (bgo#727779).
* Sun Feb  9 2014 zaitor@opensuse.org
- Update to version 1.2.3:
  + Bugs fixed: bgo#696495, bgo#722672, bgo#722672.
- Changes from version 1.2.2:
  + Bugs fixed: bgo#691617, bgo#693772, bgo#697806, bgo#704161.
* Mon Dec  2 2013 hillwood@linuxfans.org
- enable vdpau and vaapi for x86, add enable-vdpau.patch.
* Tue Nov 19 2013 reddwarf@opensuse.org
- Update to 1.2.1
* Sat Nov  9 2013 reddwarf@opensuse.org
- Update to 1.2.0
  * It continues using the internal libav copy. It may contain
    security bugs.
* Sat Aug 31 2013 zaitor@opensuse.org
- Update to version 1.0.10:
  + Fix bz2 configure check for Windows.
- Changes from version 1.0.9:
  + Enable SIMD optimizations on OS/X, improving performance a lot
    in many cases.
  + Bugs fixed: bgo#704442.
- Changes from version 1.0.8:
  + gst-libav: internal libav snapshot version bumped to v0.8.8.
- Changes from version 1.0.7:
  + Update to libav 0.8.6.
  + Bugs fixed: bgo#697548, bgo#697617.
- Changes from version 1.0.6:
  + avviddec: fix H.264 decoding errors in some files by disabling
    multi-threaded decoding.
  + libav:
  - Fix checks for internal libav configure options.
  - Update to 0.8.5 release.
  + Bugs fixed: bgo#691723, bgo#694230.
- Changes from version 1.0.5:
  + Pass CC, LD, AS, AR and NM to the libav configure if set.
- Changes from version 1.0.4:
  + G.726 decoder fixes.
  + Bugs fixed: bgo#689975.
- Changes from version 1.0.3:
  + avcodecmap: Y41B is YUV411P, not YUV410P.
- Changes from version 1.02:
  + Update internal libav snapshot to 0.8.4 release which includes
    many crasher and CVE fixes.
- Add pkgconfig(bzip2) BuildRequires, in order to support bz2
  tracks via the matroska demuxer.
- Explicitly list built plugins, so we don't loose any on updates.
* Thu Oct 11 2012 reddwarf@opensuse.org
- Initial version
